==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/is.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Myndasafn",
    "There was a problem reading files from this album" : "Það kom upp vandamál við að lesa skrár úr þessu albúmi",
    "Aborting preview. Could not find the file" : "Hætti forskoðun. Gat ekki fundið skrána",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "No compatible server found at {remote}" : "Enginn samhæfður vefþjónn fannst á {remote}",
    "Invalid server url" : "Ógild URI-slóð vefþjóns",
    "Gallery view" : "Myndasafnssýn",
    "Could not load the description" : "Gat ekki hlaðið inn lýsingunni",
    "Could not load the description: " : "Gat ekki hlaðið inn lýsingunni: ",
    "Copyright" : "Höfundarréttur",
    "Could not load the copyright notice: " : "Gat ekki hlaðið inn höfundarréttarklásúlu: ",
    "Copyright notice" : "Höfundarréttarklásúla",
    "Link to copyright document" : "Tenging í höfundarréttarskjal",
    "This application may not work properly on your browser." : "Ekki er víst að þetta forrit virki rétt í vafranum þínum.",
    "For an improved experience, please install one of the following alternatives" : "Til að nýta alla eiginleika kerfisins, settu þá upp einn af eftirfarandi valkostum",
    "Your browser is not supported!" : "Það er ekki stuðningur við vafrann þinn!",
    "please install one of the following alternatives" : "settu upp einn af eftirfarandi valkostum",
    "Album cannot be shown" : "Ekki er hægt að birta albúmið",
    "No media files found" : "Engar margmiðlunarskrár fundust",
    "Upload pictures in the files app to display them here" : "Sendu inn myndir í skráaappinu svo að þær birtist hér",
    "Upload new files via drag and drop or by using the [+] button above" : "Sendu inn nýjar skrár með því að draga/sleppa eða með [+] hnappnum hér fyrir ofan",
    "Configuration error" : "Villa í stillingum",
    "New" : "Nýtt",
    "Hide Album" : "Fela albúm",
    "Could not hide album" : "Gat ekki falið albúm",
    "Error loading slideshow template" : "Villa við að hlaða inn sniðmáti fyrir skyggnusýningu",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Villa!</strong> Gat ekki útbúið forskoðun fyrir þessa skrá.<br>Farðu yfir á næstu skyggnu á meðan við fjarlægjum þessa mynd úr skyggnusýningunni",
    "Next" : "Næst",
    "Play" : "Afspilun",
    "Pause" : "Í bið",
    "Previous" : "Fyrra",
    "Close" : "Loka",
    "Download" : "Niðurhal",
    "Toggle background" : "Víxla bakgrunni",
    "Delete" : "Eyða",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "Upload" : "Senda inn",
    "Error" : "Villa",
    "Error while sharing" : "Villa við deilingu",
    "Error while unsharing" : "Villa við að hætta deilingu",
    "Error while changing permissions" : "Villa við að breyta aðgangsheimildum",
    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
    "Shared with you by {owner}" : "Deilt með þér af {owner}",
    "Share with users or groups …" : "Deila með notendum eða hópum ...",
    "Share with users, groups or remote users …" : "Deila með notendum, hópa eða ytri notendum ...",
    "Share" : "Deila",
    "Share link" : "Deila tengli",
    "The public link will expire no later than {days} days after it is created" : "Almenningstengillinn rennur út eigi síðar en {days} dögum eftir að hann er útbúinn",
    "Link" : "Tengill",
    "Password protect" : "Verja með lykilorði",
    "Password" : "Lykilorð",
    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
    "Allow editing" : "Leyfa breytingar",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "Set expiration date" : "Setja gildistíma",
    "Expiration" : "Rennur út",
    "Expiration date" : "Gildir til",
    "An error occured. Please try again" : "Villa kom upp. Endilega reyndu aftur",
    "Adding user..." : "Bæta við notanda...",
    "group" : "hópur",
    "remote" : "fjartengt",
    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
    "Error while retrieving shares" : "Villa við að ná í deildar sameignir",
    "Unshare" : "Hætta deilingu",
    "notify by email" : "tilkynna með tölvupósti",
    "can share" : "getur deilt",
    "can edit" : "getur breytt",
    "access control" : "aðgangsstýring",
    "create" : "búa til",
    "change" : "breyta",
    "delete" : "eyða",
    "Password protected" : "Verja með lykilorði",
    "Error unsetting expiration date" : "Villa við að aftengja gildistíma",
    "Error setting expiration date" : "Villa við að setja gildistíma",
    "Sending ..." : "Sendi ...",
    "Email sent" : "Tölvupóstur sendur",
    "Warning" : "Aðvörun",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Sort by date" : "Raða eftir dagsetningu",
    "Sort by name" : "Raða eftir heiti",
    "Cancel upload" : "Hætta við innsendingu",
    "Album information" : "Upplýsingar um albúm",
    "File list" : "Skráalisti",
    "Sorry, this file could not be found." : "Því miður, þessi skrá fannst ekki.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the wrong file ID was provided" : "rangt auðkenni skráar var gefið",
    "the file was removed" : "skráin var fjarlægð",
    "the file is corrupt" : "skráin er skemmd",
    "the encryption key is missing" : "dulritunarlykil vantar",
    "Here is the error message returned by the server: " : "Hér er villumeldingin sem kom frá þjóninum:",
    "Sorry, but the server could not fulfill your request." : "Því miður gat netþjónninn ekki uppfyllt fyrirspurnina þína.",
    "Possible reasons for the problem:" : "Mögulegar ástæður fyrir þessu vandamáli:",
    "a conflicting app was installed" : "app sem veldur árekstri var sett upp",
    "a required component is missing or was disconnected" : "nauðsynlega forritseiningu vantar eða er aftengd",
    "the filesystem is not readable" : "skráakerfið er ekki læsilegt",
    "For more information, please contact your friendly ownCloud administrator." : "Til að fá nánari upplýsingar, hafðu samband við vinalega ownCloud kerfisstjórann.",
    "Sorry, this link doesn't seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "the item was removed" : "atriðið var fjarlægt",
    "the link has expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more information, please ask the person who has sent you this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "Add to your Nextcloud" : "Bæta í þitt eigið Nextcloud",
    "Picture view" : "Myndasýn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/is.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Myndasafn",
    "There was a problem reading files from this album" : "Það kom upp vandamál við að lesa skrár úr þessu albúmi",
    "Aborting preview. Could not find the file" : "Hætti forskoðun. Gat ekki fundið skrána",
    "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
    "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
    "No compatible server found at {remote}" : "Enginn samhæfður vefþjónn fannst á {remote}",
    "Invalid server url" : "Ógild URI-slóð vefþjóns",
    "Could not load the description" : "Gat ekki hlaðið inn lýsingunni",
    "Could not load the description: " : "Gat ekki hlaðið inn lýsingunni: ",
    "Copyright" : "Höfundarréttur",
    "Could not load the copyright notice: " : "Gat ekki hlaðið inn höfundarréttarklásúlu: ",
    "Copyright notice" : "Höfundarréttarklásúla",
    "Link to copyright document" : "Tenging í höfundarréttarskjal",
    "This application may not work properly on your browser." : "Ekki er víst að þetta forrit virki rétt í vafranum þínum.",
    "For an improved experience, please install one of the following alternatives" : "Til að nýta alla eiginleika kerfisins, settu þá upp einn af eftirfarandi valkostum",
    "Your browser is not supported!" : "Það er ekki stuðningur við vafrann þinn!",
    "please install one of the following alternatives" : "settu upp einn af eftirfarandi valkostum",
    "Album cannot be shown" : "Ekki er hægt að birta albúmið",
    "No media files found" : "Engar margmiðlunarskrár fundust",
    "Upload pictures in the Files app to display them here" : "Sendu inn myndir í skráaappinu svo að þær birtist hér",
    "Upload new files via drag and drop or by using the [+] button above" : "Sendu inn nýjar skrár með því að draga/sleppa eða með [+] hnappnum hér fyrir ofan",
    "Configuration error" : "Villa í stillingum",
    "New" : "Nýtt",
    "Hide Album" : "Fela albúm",
    "Could not hide album" : "Gat ekki falið albúm",
    "Error loading slideshow template" : "Villa við að hlaða inn sniðmáti fyrir skyggnusýningu",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Villa!</strong> Gat ekki útbúið forskoðun fyrir þessa skrá.<br>Farðu yfir á næstu skyggnu á meðan við fjarlægjum þessa mynd úr skyggnusýningunni",
    "Next" : "Næst",
    "Play" : "Afspilun",
    "Pause" : "Í bið",
    "Previous" : "Fyrra",
    "Close" : "Loka",
    "Download" : "Niðurhal",
    "Toggle background" : "Víxla bakgrunni",
    "Delete" : "Eyða",
    "Could not create file \"{file}\" because it already exists" : "Gat ekki búið til skrána \"{file}\" vegna þess að hún er þegar til",
    "Could not create file \"{file}\"" : "Gat ekki búið til skrána \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" er ógilt skráarheiti.",
    "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
    "Upload" : "Senda inn",
    "Error" : "Villa",
    "Error while sharing" : "Villa við deilingu",
    "Error while unsharing" : "Villa við að hætta deilingu",
    "Error while changing permissions" : "Villa við að breyta aðgangsheimildum",
    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
    "Shared with you by {owner}" : "Deilt með þér af {owner}",
    "Share with users or groups …" : "Deila með notendum eða hópum ...",
    "Share with users, groups or remote users …" : "Deila með notendum, hópa eða ytri notendum ...",
    "Share" : "Deila",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Deila með fólki í öðrum skýjum með auðkenninu notandanafn@dæmi.is/nextcloud",
    "Share link" : "Deila tengli",
    "The public link will expire no later than {days} days after it is created" : "Almenningstengillinn rennur út eigi síðar en {days} dögum eftir að hann er útbúinn",
    "Link" : "Tengill",
    "Password protect" : "Verja með lykilorði",
    "Password" : "Lykilorð",
    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
    "Allow editing" : "Leyfa breytingar",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "Set expiration date" : "Setja gildistíma",
    "Expiration" : "Rennur út",
    "Expiration date" : "Gildir til",
    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
    "No users found for {search}" : "Engir notendur fundust fyrir {search}",
    "An error occured. Please try again" : "Villa kom upp. Endilega reyndu aftur",
    "Adding user..." : "Bæta við notanda...",
    "group" : "hópur",
    "remote" : "fjartengt",
    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
    "Error while retrieving shares" : "Villa við að ná í deildar sameignir",
    "Unshare" : "Hætta deilingu",
    "notify by email" : "tilkynna með tölvupósti",
    "can share" : "getur deilt",
    "can edit" : "getur breytt",
    "access control" : "aðgangsstýring",
    "create" : "búa til",
    "change" : "breyta",
    "delete" : "eyða",
    "Password protected" : "Verja með lykilorði",
    "Error unsetting expiration date" : "Villa við að aftengja gildistíma",
    "Error setting expiration date" : "Villa við að setja gildistíma",
    "Sending ..." : "Sendi ...",
    "Email sent" : "Tölvupóstur sendur",
    "Warning" : "Aðvörun",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Sort by date" : "Raða eftir dagsetningu",
    "Sort by name" : "Raða eftir heiti",
    "Cancel upload" : "Hætta við innsendingu",
    "Album information" : "Upplýsingar um albúm",
    "File list" : "Skráalisti",
    "Sorry, this file could not be found." : "Því miður, þessi skrá fannst ekki.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the wrong file ID was provided" : "rangt auðkenni skráar var gefið",
    "the file was removed" : "skráin var fjarlægð",
    "the file is corrupt" : "skráin er skemmd",
    "the encryption key is missing" : "dulritunarlykil vantar",
    "Here is the error message returned by the server: " : "Hér er villumeldingin sem kom frá þjóninum:",
    "For more information, please contact your friendly Nextcloud administrator." : "Til að fá nánari upplýsingar, hafðu samband við vinalega Nextcloud kerfisstjórann.",
    "Sorry, but the server could not fulfill your request." : "Því miður gat netþjónninn ekki uppfyllt fyrirspurnina þína.",
    "Possible reasons for the problem:" : "Mögulegar ástæður fyrir þessu vandamáli:",
    "a conflicting app was installed" : "app sem veldur árekstri var sett upp",
    "a required component is missing or was disconnected" : "nauðsynlega forritseiningu vantar eða er aftengd",
    "the filesystem is not readable" : "skráakerfið er ekki læsilegt",
    "Sorry, this link doesn't seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "the item was removed" : "atriðið var fjarlægt",
    "the link has expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more information, please ask the person who has sent you this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "Add to your Nextcloud" : "Bæta í þitt eigið Nextcloud",
    "Picture view" : "Myndasýn",
    "Gallery view" : "Myndasafnssýn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
